@@ -33,10 +33,10 @@
 #include <tqfileinfo.h>
 
 //KDE includes
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 
 //Sword includes
 #include <swbuf.h>
@@ -76,7 +76,7 @@ CSwordModuleInfo::CSwordModuleInfo(sword::SWModule * module, CSwordBackend * con
 
     if (backend()) {
         if (hasVersion() && (minimumSwordVersion() > sword::SWVersion::currentVersion)) {
-            qWarning("The module \"%s\" requires a newer Sword library. Please update to \"Sword %s\".",
+            tqWarning("The module \"%s\" requires a newer Sword library. Please update to \"Sword %s\".",
                      name().latin1(), (const char *)minimumSwordVersion());
         }
     }
@@ -164,23 +164,23 @@ const bool CSwordModuleInfo::unlockKeyIsValid() {
         : TQString::fromLatin1( m_module->getRawEntryBuf().c_str() );
 
     if (test.isEmpty()) {
-        qWarning("Unlock key of module %s is NOT valid", name().latin1());
+        tqWarning("Unlock key of module %s is NOT valid", name().latin1());
         return false;
     }
 
     for (unsigned int i = 0; i <= test.length(); i++) {
         if ( !test[i].isPrint() && !test[i].isNull() ) {
-            qWarning("Unlock key of module %s is NOT valid", name().latin1());
+            tqWarning("Unlock key of module %s is NOT valid", name().latin1());
             return false;
         }
     }
 
-    qDebug("Unlock key of module %s is valid", name().latin1());
+    tqDebug("Unlock key of module %s is valid", name().latin1());
     return true;
 }
 
 const TQString CSwordModuleInfo::getGlobalBaseIndexLocation() {
-    return KGlobal::dirs()->saveLocation("data", "bibletime/indices");
+    return TDEGlobal::dirs()->saveLocation("data", "bibletime/indices");
 }
 
 const TQString CSwordModuleInfo::getModuleBaseIndexLocation() const {
@@ -200,8 +200,8 @@ const bool CSwordModuleInfo::hasIndex() { //this will return true only
     }
 
     //first check if the index version and module version are ok
-    util::scoped_ptr<KConfig> indexconfig(
-        new KConfig( getModuleBaseIndexLocation() + TQString("/bibletime-index.conf") )
+    util::scoped_ptr<TDEConfig> indexconfig(
+        new TDEConfig( getModuleBaseIndexLocation() + TQString("/bibletime-index.conf") )
     );
 
     if (hasVersion()) {
@@ -210,7 +210,7 @@ const bool CSwordModuleInfo::hasIndex() { //this will return true only
         }
     }
     if (indexconfig->readEntry("index-version") != TQString::number( INDEX_VERSION )) {
-        qDebug("%s: INDEX_VERSION is not compatible with this version of BibleTime.", name().latin1());
+        tqDebug("%s: INDEX_VERSION is not compatible with this version of BibleTime.", name().latin1());
         return false;
     }
 
@@ -297,8 +297,8 @@ void CSwordModuleInfo::buildIndex() {
         //If it is a sword-heading, store in buffer and index later in Verse X:1
         if (vk) {
             if (vk->Verse() == 0) {
-                //qWarning("key is %s", key->getText());
-		//qWarning("text is %s", m_module->StripText());
+                //tqWarning("key is %s", key->getText());
+		//tqWarning("text is %s", m_module->StripText());
                 textBuffer.append( m_module->StripText() );
                 continue;
             }
@@ -369,7 +369,7 @@ void CSwordModuleInfo::buildIndex() {
 #else // CLUCENE_V2
                 doc->add(*lucene::document::Field::UnStored(_T("strong"), wcharBuffer));
 #endif // CLUCENE_V2
-                //qWarning("Adding strong %s", attListI->second["Lemma"].c_str());
+                //tqWarning("Adding strong %s", attListI->second["Lemma"].c_str());
             }
             if (attListI->second.find("Morph") != attListI->second.end()) {
                 lucene_utf8towcs(wcharBuffer, attListI->second["Morph"], BT_MAX_LUCENE_FIELD_LENGTH);
@@ -399,7 +399,7 @@ void CSwordModuleInfo::buildIndex() {
     writer->close();
 
     TQString configFilename = getModuleStandardIndexLocation() + TQString("/../bibletime-index.conf");
-    util::scoped_ptr<KConfig> indexconfig( new KConfig( configFilename ) );
+    util::scoped_ptr<TDEConfig> indexconfig( new TDEConfig( configFilename ) );
     if (hasVersion()) {
         indexconfig->writeEntry("module-version", config(CSwordModuleInfo::ModuleVersion) );
     }
@@ -480,7 +480,7 @@ const bool CSwordModuleInfo::searchIndexed(const TQString& searchedText, sword::
             }
         }
     } catch (...) {
-        qWarning("CLucene exception");
+        tqWarning("CLucene exception");
         return false;
     }
 
